@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: error-viewer.c,v 1.13.2.1 2004/09/26 16:22:39 chpe Exp $
+ *  $Id: error-viewer.c,v 1.15 2004/10/05 11:28:39 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -200,7 +200,6 @@ delete_window_cb (GtkWidget *widget,
 static void
 build_ui (ErrorViewer *dialog)
 {
-	GdkPixbuf *icon;
 	GtkListStore *store;
 	GtkTreeView *treeview;
 	GtkCellRenderer *renderer;
@@ -211,6 +210,9 @@ build_ui (ErrorViewer *dialog)
 	priv->treeview = ephy_dialog_get_control (EPHY_DIALOG (dialog),
 						  properties[PROP_TREEVIEW].id);
 
+	gtk_window_set_icon_name (GTK_WINDOW (priv->window),
+				  GTK_STOCK_DIALOG_ERROR);
+
 	g_signal_connect (priv->window, "delete-event",
 			  G_CALLBACK (delete_window_cb), NULL);
 
@@ -247,12 +249,6 @@ build_ui (ErrorViewer *dialog)
 				 GTK_TREE_MODEL (store));
 
 	priv->model = GTK_TREE_MODEL (store);
-
-	icon = gtk_widget_render_icon (GTK_WIDGET (priv->window),
-				       GTK_STOCK_DIALOG_ERROR,
-				       GTK_ICON_SIZE_MENU,
-				       NULL);
-	gtk_window_set_icon (GTK_WINDOW (priv->window), icon);
 }
 
 static void
