@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: sample-mozilla.c,v 1.5 2004/11/01 14:24:35 chpe Exp $
+ *  $Id: sample-mozilla.c,v 1.6 2004/12/08 15:33:53 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -38,7 +38,7 @@ register_module (GTypeModule *module)
 
 #ifdef ENABLE_NLS
        /* Initialise the i18n stuff */
-        bindtextdomain (GETTEXT_PACKAGE, EPHY_PLUGINS_LOCALEDIR);
+        bindtextdomain (GETTEXT_PACKAGE, EPHY_EXTENSIONS_LOCALEDIR);
         bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");	
 #endif /* ENABLE_NLS */
 
